@@ -102,7 +102,7 @@ class _Matcher(_RequestHistoryTracker):
             url_parts = urlparse.urlparse(url)
             self._scheme = url_parts.scheme.lower()
             self._netloc = url_parts.netloc.lower()
-            self._path = url_parts.path or '/'
+            self._path = urlparse.quote(url_parts.path or '/')
             self._query = url_parts.query
 
             if not case_sensitive:
@@ -252,7 +252,9 @@ class Adapter(BaseAdapter, _RequestHistoryTracker):
             if resp is not None:
                 request._matcher = weakref.ref(matcher)
                 resp.connection = self
-                logger.debug('{} {} {}'.format(request._request.method,request._request.url, resp.status_code))
+                logger.debug('{} {} {}'.format(request._request.method,
+                                               request._request.url,
+                                               resp.status_code))
                 return resp
 
         raise exceptions.NoMockAddress(request)
